package Glib::Object::Introspection::Install::Files;

$self = {
          'deps' => [
                      'Glib'
                    ],
          'inc' => '-I/usr/include/gobject-introspection-1.0 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -pthread -pthread -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include ',
          'libs' => '-lgirepository-1.0 -lgobject-2.0 -lglib-2.0 -lintl -Wl,--export-all-symbols -lgmodule-2.0 -pthread -lglib-2.0 -lintl -L/usr/lib/../lib -lffi',
          'typemaps' => []
        };

@deps = @{ $self->{deps} };
@typemaps = @{ $self->{typemaps} };
$libs = $self->{libs};
$inc = $self->{inc};

	$CORE = undef;
	foreach (@INC) {
		if ( -f $_ . "/Glib/Object/Introspection/Install/Files.pm") {
			$CORE = $_ . "/Glib/Object/Introspection/Install/";
			last;
		}
	}

	sub deps { @{ $self->{deps} }; }

	sub Inline {
		my ($class, $lang) = @_;
		+{ map { (uc($_) => $self->{$_}) } qw(inc libs typemaps) };
	}

1;
